/******************************************************************************/
/*  ONC_getlos_c                                                              */
/*  ֹȵ NAIF ID äơβǤLine of Sight (LOS) ٥ */
/*  ܥȤФ֤ͤONCѡ                               */
/*                                                                            */
/*  v0.1 -- June 24, 2005 -- Naru Hirata Naru Hirata, Kobe Univ.              */
/*  LISM_getlos.c ܿ                                                    */
/*  Ȥꤢ r = f x tan(theta) §ǵ                                  */
/*                                                                            */
/*  Return value                                                              */
/*  1               Normal.                                                   */
/*  0               Some variables cannot be found in the kernel pool.        */
/*                                                                            */
/*  VARIABLE        I/O  DESCRIPTION                                          */
/*  --------------- ---  ---------------------------------------------------- */
/*   instid          I   NAIF ID of an instrument.                            */
/*   pixel[2]        I   Pixel coordinate (0: horizontal, 1: vertical).       */
/*   los_vector [3]  O   LOS vector.                                          */
/*                                                                            */
/******************************************************************************/

#define _GNU_SOURCE 
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include "SpiceUsr.h"
#define  STRLEN 100
#define  ROOM    10

int ONC_getlos_c ( SpiceInt        instid,
                    SpiceDouble     pixel[2],
                    SpiceDouble     los_vector [3] )
{
	
	SpiceDouble      focal_length;
	SpiceDouble      center[2];
	SpiceDouble      pixel_size;
	
//	SpiceDouble      r; //radial distance from the boresight direction
	SpiceDouble      d_h; //horizontal distance from the boresight direction
	SpiceDouble      d_v; //vertical distance from the boresight direction
//	SpiceDouble      theta; //viewing angle [radians]
	
	//Name of the variable whose value is to be returned from the kernel pool.
	SpiceChar        var_name[STRLEN]; 
	SpiceInt         n_return;
	SpiceBoolean     found_fl,found_center,found_pixel_size;
	
	sprintf (var_name,"INS%d_FOCAL_LENGTH",instid);
	gdpool_c (var_name,0,ROOM,&n_return,&focal_length,&found_fl);
	
	sprintf (var_name,"INS%d_CENTER",instid);
	gdpool_c (var_name,0,ROOM,&n_return,center,&found_center);
	
	sprintf (var_name,"INS%d_PIXEL_SIZE",instid);
	gdpool_c (var_name,0,ROOM,&n_return,&pixel_size,&found_pixel_size);
	
	//õƤܤ kernel pool ˤʤä饨顼
	if (!found_fl||!found_center||!found_pixel_size) return(0);
	
	
#ifdef DEBUG
	printf ("focal length: %f\n", focal_length);
	printf ("center: %f %f\n", center[0],center[1]);
	printf ("pixel size: %f\n", pixel_size);
#endif /*DEBUG*/
	
//	d_h = - (pixel[0] - center[0]) * pixel_size;
//	d_v = - (pixel[1] - center[1]) * pixel_size;
	
//ɸ餬դˤʤäƤ褦ʤΤǽ
	d_h = (pixel[0] - center[0]) * pixel_size;
	d_v = (pixel[1] - center[1]) * pixel_size;
//	r = (pixel - center[0]) * pixel_size;
//	theta = atan2 (r,focal_length);
	
	// r = f x tan(theta) §ξ硤٥ȥ (0,r,f) ˤʤ
	los_vector[0] = d_h;
	los_vector[1] = d_v;
	los_vector[2] = focal_length;
	
#ifdef DEBUG
	printf ("los_vector: %f %f %f\n", los_vector[0], los_vector[1], los_vector[2]);
//	printf ("r: %f\n", r);
//	printf ("theta: %f\n", theta*dpr_c());
#endif /*DEBUG*/
	return(1);
}